@@ -162,7 +162,7 @@ class RecurrenceView(BrowserView):
         # Total number of occurrences:
         num_occurrences += batch_size + start
 
-        max_batch = (num_occurrences - 1)//batch_size
+        max_batch = (num_occurrences - 1) // batch_size
         if last_batch > max_batch:
             last_batch = max_batch
             first_batch = max(0, max_batch - (BATCH_DELTA * 2))
@@ -171,6 +171,11 @@ class RecurrenceView(BrowserView):
             ((x * batch_size) + 1, (x + 1) * batch_size)
             for x in range(first_batch, last_batch + 1)
         ]
+        # correct number of occurrences in current batch
+        (cur_batch_start, cur_batch_end) = batches[cur_batch]
+        if cur_batch_end > len(occurrences):
+            batches[cur_batch] = (cur_batch_start, len(occurrences))
+
         batch_data = {'start': start,
                       'end': num_occurrences,
                       'batch_size': batch_size,
